==> virtual-additions-4.0.0%2B1.21.9-sources.jar: com/github/suninvr/virtualadditions/block/SilkFluffBlock.java <==
package com.github.suninvr.virtualadditions.block;

import com.github.suninvr.virtualadditions.registry.VAEntityTypeTags;
import com.mojang.serialization.MapCodec;
import net.minecraft.class_10;
import net.minecraft.class_10774;
import net.minecraft.class_1297;
import net.minecraft.class_1922;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_243;
import net.minecraft.class_259;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_3726;
import net.minecraft.class_3727;

@SuppressWarnings("deprecation")
public class SilkFluffBlock extends class_2248 {
    public static final MapCodec<SilkFluffBlock> CODEC = method_54094(SilkFluffBlock::new);
    private static final class_243 movement = new class_243(0.85, 1.0, 0.85);

    public SilkFluffBlock(class_2251 settings) {
        super(settings);
    }

    @Override
    protected MapCodec<? extends class_2248> method_53969() {
        return field_46280;
    }

    @Override
    protected boolean method_9516(class_2680 state, class_10 type) {
        return true;
    }

    @Override
    public void method_9548(class_2680 state, class_1937 world, class_2338 pos, class_1297 entity, class_10774 handler) {
        if (entity.method_5864().method_20210(VAEntityTypeTags.PASSES_THROUGH_WEBBED_SILK)) entity.method_5844(state, movement);
    }

    @Override
    public class_265 method_9549(class_2680 state, class_1922 world, class_2338 pos, class_3726 context) {
        if (context instanceof class_3727 entityContext) {
            if (entityContext.method_32480() != null) {
                class_1297 entity = entityContext.method_32480();
                if (entity.method_5864().method_20210(VAEntityTypeTags.PASSES_THROUGH_WEBBED_SILK)) return class_259.method_1073();
            }
        }
        return class_259.method_1077();
    }

    @Override
    public class_265 method_25959(class_2680 state, class_1922 world, class_2338 pos) {
        return class_259.method_1073();
    }

    @Override
    public class_265 method_26159(class_2680 state, class_1922 world, class_2338 pos, class_3726 context) {
        return class_259.method_1073();
    }
}

==> virtual-additions-4.0.1%2B1.21.10-sources.jar: com/github/suninvr/virtualadditions/block/SilkFluffBlock.java <==
package com.github.suninvr.virtualadditions.block;

import com.github.suninvr.virtualadditions.registry.VAEntityTypeTags;
import com.mojang.serialization.MapCodec;
import net.minecraft.class_10;
import net.minecraft.class_10774;
import net.minecraft.class_1297;
import net.minecraft.class_1922;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_243;
import net.minecraft.class_259;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_3726;
import net.minecraft.class_3727;

@SuppressWarnings("deprecation")
public class SilkFluffBlock extends class_2248 {
    public static final MapCodec<SilkFluffBlock> CODEC = method_54094(SilkFluffBlock::new);
    private static final class_243 movement = new class_243(0.85, 1.0, 0.85);

    public SilkFluffBlock(class_2251 settings) {
        super(settings);
    }

    @Override
    protected MapCodec<? extends class_2248> method_53969() {
        return field_46280;
    }

    @Override
    protected boolean method_9516(class_2680 state, class_10 type) {
        return true;
    }

    @Override
    public void method_9548(class_2680 state, class_1937 world, class_2338 pos, class_1297 entity, class_10774 handler, boolean bl) {
        if (entity.method_5864().method_20210(VAEntityTypeTags.PASSES_THROUGH_WEBBED_SILK)) entity.method_5844(state, movement);
    }

    @Override
    public class_265 method_9549(class_2680 state, class_1922 world, class_2338 pos, class_3726 context) {
        if (context instanceof class_3727 entityContext) {
            if (entityContext.method_32480() != null) {
                class_1297 entity = entityContext.method_32480();
                if (entity.method_5864().method_20210(VAEntityTypeTags.PASSES_THROUGH_WEBBED_SILK)) return class_259.method_1073();
            }
        }
        return class_259.method_1077();
    }

    @Override
    public class_265 method_25959(class_2680 state, class_1922 world, class_2338 pos) {
        return class_259.method_1073();
    }

    @Override
    public class_265 method_26159(class_2680 state, class_1922 world, class_2338 pos, class_3726 context) {
        return class_259.method_1073();
    }
}
